.. _special:

=================
Special Structures
=================

Classes to generate special quasi-random structures (SQS).

.. automodule:: smol.capp.generate.special.sqs
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: SQSGenerator
